@@ -937,6 +937,47 @@ class TableManager:
         return False
 
 
+    @property
+    def indexes(self):
+        '''
+            Get this TableManager's indexes
+
+
+            `default`:[]
+
+
+            Meta
+            ----------
+            `@author`: Colemen Atwood
+            `@created`: 07-21-2022 10:00:45
+            `@memberOf`: TableManager
+            `@property`: indexes
+        '''
+        return obj.get_arg(self.data,['indexes'],[],(list))
+
+    @property
+    def fulltext_indexes(self):
+        '''
+            Get this TableManager's fulltext_indexes
+
+
+            `default`:None
+
+
+            Meta
+            ----------
+            `@author`: Colemen Atwood
+            `@created`: 07-21-2022 10:01:57
+            `@memberOf`: TableManager
+            `@property`: fulltext_indexes
+        '''
+        value = []
+        for idx in self.indexes:
+            if idx['index_type'] == "fulltext":
+                value.append(value)
+        return value
+
+
 
     @property
     def table_dir_path(self):
