@@ -1298,7 +1298,6 @@ def get_files(search_path=False, **kwargs):
     if isinstance(search_path, list) is False:
         search_path = [search_path]
 
-    dicts = _obj.get_kwarg(['dicts'], True, bool, **kwargs)
     threaded = _obj.get_kwarg(['threaded', 'thread'], True, bool, **kwargs)
     recursive = _obj.get_kwarg(['recursive', 'recurse'], True, bool, **kwargs)
 
@@ -1348,7 +1347,6 @@ def get_files(search_path=False, **kwargs):
                 include=include,
                 extensions=extension_array,
                 include_meta_data=include_meta_data,
-                dicts=dicts,
                 show_index_count=show_index_count)
             return gft.master()
     # print(_json.dumps(extension_array, indent=4))
@@ -1605,7 +1603,6 @@ class GetFilesThreaded:
         if isinstance(self.search_path, list) is False:
             self.search_path = [self.search_path]
 
-        self.dicts = _obj.get_kwarg(['dicts'], True, bool, **kwargs)
         self.recursive = _obj.get_kwarg(['recursive', 'recurse'], True, bool, **kwargs)
 
         self.data_include = _obj.get_kwarg(['data include'], [], (list, str), **kwargs)
@@ -1677,9 +1674,6 @@ class GetFilesThreaded:
                 if file_ext not in self.extension_array:
                     return
 
-        if self.dicts is False:
-            file_data = _f.File(file_path,file_data)
-
         self.file_array.append(file_data)
         if self.show_index_count is True:
             print(f"files indexed: {len(self.file_array)}                                             ",end="\r",flush=True)
