@@ -25,6 +25,7 @@ from faker import Faker as _Faker
 import utils.random_utils.rand_utils as _ru
 import utils.dict_utils as _obj
 import utils.string_utils as _csu
+import utils.file_utils as _f
 # import facades.rand_utils_facade as rand
 
 
@@ -179,6 +180,42 @@ def rand(length=12, **kwargs):
 
     return ''.join(_random.SystemRandom().choice(choices) for _ in range(length))
 
+def letter(length=1,upper=True,lower=True):
+    '''
+        Generate a random letter or multiple letters.
+
+        ----------
+
+        Arguments
+        -------------------------
+        [`length`=1] {int}
+            The number of characters that the string should contain.
+
+        [`upper`=True] {bool}
+            If True, uppercase letters are included.
+            ABCDEFGHIJKLMNOPQRSTUVWXYZ
+
+        [`lower`=True] {bool}
+            If True, lowercase letters are included.
+            abcdefghijklmnopqrstuvwxyz
+
+        Return {str}
+        ----------------------
+        The randomly generated letter(s)
+
+        Meta
+        ----------
+        `author`: Colemen Atwood
+        `created`: 07-30-2022 10:03:25
+        `memberOf`: rand_generation
+        `version`: 1.0
+        `method_name`: letter
+        * @xxx [07-30-2022 10:04:30]: documentation for letter
+    '''
+
+
+    return rand(length,upper_case=upper,lower_case=lower,digits=False)
+
 def css_class(length=12):
     '''
         Generate a random string that is safe to use as a css class.
@@ -206,10 +243,10 @@ def css_class(length=12):
 
 
     value = rand(length)
-    value = _re.sub(r'^[0-9]',"x",value)
+    rand(1,digits=False)
+    value = _re.sub(r'^[0-9]',letter(),value)
     return value
 
-
 def text(minimum=10,maximum=500,null_bias=0):
     '''
         Wrapper method for faker().text()
@@ -1031,3 +1068,115 @@ def user(**kwargs)->dict:
     data['phone'] = fake.phone_number()
 
     return data
+
+
+def file_extension():
+    return _rand_option(_ru.COMMON_FILE_EXTENSIONS)
+
+def dir_path(**kwargs):
+    '''
+        Generate a random directory path.
+
+        ----------
+
+        Arguments
+        -------------------------
+        `arg_name` {type}
+                arg_description
+
+        Keyword Arguments
+        -------------------------
+        [`depth`=2] {int}
+            How many directories should be generated.
+
+        [`divider`="\\"] {str}
+            The directory divider
+
+        [`drive`=random] {str}
+            The drive letter
+
+        Return {str}
+        ----------------------
+        The randomly generated dir path.
+
+        Meta
+        ----------
+        `author`: Colemen Atwood
+        `created`: 07-30-2022 10:41:55
+        `memberOf`: rand_generation
+        `version`: 1.0
+        `method_name`: dir_path
+        * @xxx [07-30-2022 10:44:25]: documentation for dir_path
+    '''
+
+
+    depth = _obj.get_kwarg(['depth'], 2, (int), **kwargs)
+    if depth < 0:
+        depth = 0
+    divider = _obj.get_kwarg(['divider'], "\\", (str), **kwargs)
+    drive = _obj.get_kwarg(['drive'], letter(1,True,False), (str), **kwargs)    
+    dirs = []
+    for _ in range(depth):
+        dirs.append(_rand_noun())
+    dirs = divider.join(dirs)
+    path = f"{drive}:{divider}"
+    if len(dirs) > 0:
+        path = f"{drive}:{divider}{dirs}{divider}"
+    return path
+
+def file_path(**kwargs):
+    '''
+        Generate a random file path.
+
+        ----------
+
+        Keyword Arguments
+        -------------------------
+        [`depth`=2] {int}
+            How many directories should be generated.
+
+        [`divider`="\\"] {str}
+            The directory divider
+
+        [`file_name`=random] {str}
+            The name of the file, this should include the file extension.
+            If it does not have an extension, a random one is generated.
+
+        [`drive`=random] {str}
+            The drive letter
+
+        Return {str}
+        ----------------------
+        The randomly generated file path.
+
+        Meta
+        ----------
+        `author`: Colemen Atwood
+        `created`: 07-30-2022 10:22:59
+        `memberOf`: rand_generation
+        `version`: 1.0
+        `method_name`: file_path
+        * @xxx [07-30-2022 10:29:45]: documentation for file_path
+    '''
+
+
+    depth = _obj.get_kwarg(['depth'], 2, (int), **kwargs)
+    if depth < 0:
+        depth = 0
+
+    divider = _obj.get_kwarg(['divider'], "\\", (str), **kwargs)
+    file_name = _obj.get_kwarg(['file_name'], _rand_noun(), (str), **kwargs)
+    drive = _obj.get_kwarg(['drive'], letter(1,True,False), (str), **kwargs)
+
+
+    base_dir = dir_path(depth=depth,divider=divider,drive=drive)
+
+    path = f"{base_dir}{divider}{file_name}"
+
+    extension = _f.get_ext(path)
+    if len(extension) == 0:
+        path = f"{base_dir}{file_name}.{file_extension()}"
+
+    return path
+
+
