@@ -23,6 +23,7 @@ import re as _re
 import json as _json
 import shlex as _shlex
 import sqlparse as _sqlparse
+import yaml
 from typing import Union as _Union
 
 from pyparsing import And, Suppress,Dict, Word, Literal, Group, Optional, ZeroOrMore, OneOrMore, Regex, restOfLine, alphanums,nums, printables, string, CaselessKeyword,nestedExpr,ParseException,quotedString,removeQuotes,originalTextFor,delimitedList,QuotedString
@@ -268,8 +269,8 @@ def parse_column_data(value=None):
         match = list(match[0])
         default_value = _csu.strip(match[1]," ")
         
-        if _re.match(r"^[0-9\+-\.]*$",match[1]) is not None:
-            default_value = int(match[1])
+        if _re.match(r"^[0-9\+-\.]*$",default_value) is not None:
+            default_value = int(default_value)
         value = value.replace(match[0],"")
 
     # print(f"value: {value}")
@@ -571,11 +572,13 @@ def _parse_table_column_lines(lines):
             uk = parse_unique_key(line)
             if uk is not None:
                 # print(f"Unique Key Found: {uk}")
+                data['indexes'].append(uk)
                 data['unique_keys'].append(uk)
                 # data['unique_keys'] = _lu.append(data['unique_keys'],uk['unique_key'])
 
             pk = parse_primary_key(line)
             if pk is not None:
+                data['indexes'].append(pk)
                 data['primary_keys'] = _lu.append(data['primary_keys'],pk['primary_key'])
             # data['primary_keys'] = _lu.append(data['primary_keys'],parse_primary_key(line))
 
@@ -729,7 +732,9 @@ def parse_primary_key(value=None):
 
     if len(res) > 0:
         data = res.as_dict()['data']
-        new_data = {}
+        new_data = {
+            "index_type":"primary_key"
+        }
         for k,v in data.items():
             if k == "primary_key":
                 new_data[k] = v.split(",")
@@ -753,7 +758,7 @@ def parse_unique_key(value=None):
     _tick,_double_quote,_single_quote,_period = [Suppress(x) for x in list('`"\'.')]
     _quote = (_tick|_double_quote|_single_quote)
     _open_paren,_close_paren = [Suppress(x) for x in list('()')]
-    paren_word = _open_paren + Optional(_quote) + Word(alphanums + "_") + Optional(_quote) + _close_paren
+    # paren_word = _open_paren + Optional(_quote) + Word(alphanums + "_") + Optional(_quote) + _close_paren
     quoted_word = _quote + Word(alphanums + "_") + _quote
 
 
@@ -775,7 +780,8 @@ def parse_unique_key(value=None):
         data = res.as_dict()['data']
 
         new_data = {
-            "comment":comment
+            "index_type":"unique",
+            "comment":comment,
         }
         for k,v in data.items():
             if k == "columns":
@@ -829,7 +835,8 @@ def parse_fulltext_key(value=None):
         data = res.as_dict()['data']
 
         new_data = {
-            "comment":comment_value
+            "index_type":"fulltext",
+            "comment":comment_value,
         }
 
         for k,v in data.items():
@@ -1222,82 +1229,175 @@ def is_line_constraint(line:str)->bool:
         return True
     return False
 
-def parse_primary_keys(sql:str)->list:
-    '''
-        Parse the primary keys from a SQL string.
+# def parse_primary_keys(sql:str)->list:
+#     '''
+#         Parse the primary keys from a SQL string.
 
-        ----------
+#         ----------
 
-        Arguments
-        -------------------------
-        `sql` {str}
-            The SQL string to parse.
+#         Arguments
+#         -------------------------
+#         `sql` {str}
+#             The SQL string to parse.
 
-        Return {list}
-        ----------------------
-        A list of primary keys.
+#         Return {list}
+#         ----------------------
+#         A list of primary keys.
 
-        Meta
-        ----------
-        `author`: Colemen Atwood
-        `created`: 06-05-2022 20:18:46
-        `memberOf`: sql_parse
-        `version`: 1.0
-        `method_name`: parse_primary_keys
-        * @xxx [06-05-2022 20:20:08]: documentation for parse_primary_keys
-    '''
+#         Meta
+#         ----------
+#         `author`: Colemen Atwood
+#         `created`: 06-05-2022 20:18:46
+#         `memberOf`: sql_parse
+#         `version`: 1.0
+#         `method_name`: parse_primary_keys
+#         * @xxx [06-05-2022 20:20:08]: documentation for parse_primary_keys
+#     '''
 
 
-    primary_keys = []
-    match = _re.findall(r'primary\s*key\s*\(([a-zA-Z0-9_,\`\'\"\s]*)\)',sql,_re.IGNORECASE)
-    if match is not None:
-        if len(match) > 0:
-            keys = _sql.strip_sql_quotes(match[0])
-            keys = keys.split(",")
-            keys = [_csu.strip(x,[" "]) for x in keys]
-            primary_keys = keys
-        # print(match)
-    return primary_keys
+#     primary_keys = []
+#     match = _re.findall(r'primary\s*key\s*\(([a-zA-Z0-9_,\`\'\"\s]*)\)',sql,_re.IGNORECASE)
+#     if match is not None:
+#         if len(match) > 0:
+#             keys = _sql.strip_sql_quotes(match[0])
+#             keys = keys.split(",")
+#             keys = [_csu.strip(x,[" "]) for x in keys]
+#             primary_keys = keys
+#         # print(match)
+#     return primary_keys
 
-def format_sql_string(sql:str):
-    '''
-        Format an SQL string to a consistent indentation.
+# def format_sql_string(sql:str):
+#     '''
+#         Format an SQL string to a consistent indentation.
 
-        ----------
+#         ----------
 
-        Arguments
-        -------------------------
-        `sql` {string}
-            The sql string to mod.
+#         Arguments
+#         -------------------------
+#         `sql` {string}
+#             The sql string to mod.
+
+#         Return {string}
+#         ----------------------
+#         The formatted SQL
+
+#         Meta
+#         ----------
+#         `author`: Colemen Atwood
+#         `created`: 03-21-2022 12:38:32
+#         `version`: 1.0
+#         `method_name`: format_sql_string
+#         @xxx [03-21-2022 12:38:41]: documentation for format_sql_string
+#     '''
+#     if _f.exists(sql):
+#         sql = _f.readr(sql)
+
+#     sql = _csu.strip_empty_lines(sql)
+
+#     raw = sql
+#     # raw = _re.sub(r'^[\n]*','',raw)
+#     statements = _sqlparse.split(raw)
+#     new_contents = []
+#     for state in statements:
+#         state = _re.sub(r'^[\s\n]*','',state)
+#         new_state = _sqlparse.format(state, reindent=True, keyword_case='upper')
+#         new_contents.append(new_state)
+#     if len(new_contents) > 0:
+#         return "\n".join(new_contents)
+#     return False
+
+
+# def _parse_table_comment(table:Table):
+#     '''
+#         Parse the Columns YAML comment into the Column's data dictionary.
+
+#         ----------
+
+#         Arguments
+#         -------------------------
+#         `col` {Column}
+#             The instance of the column to parse.
+
+#         Meta
+#         ----------
+#         `author`: Colemen Atwood
+#         `created`: 07-03-2022 11:22:39
+#         `memberOf`: Column
+#         `version`: 1.0
+#         `method_name`: _parse_col_data
+#         * @xxx [07-03-2022 11:23:39]: documentation for _parse_col_data
+#     '''
+
+#     comment = table.comment
+#     if isinstance(comment,(str)) is False:
+#         comment = ""
+
+#     if comment is None:
+#         return None
+#     try:
+#         result = _parse_comment_yaml(comment)
+#     except yaml.scanner.ScannerError:
+#         c.con.log(f"Failed to parse comment for table: {table.name}","error")
+#         return False
+
+#     if isinstance(result,(dict)):
+#         if 'hash_id_prefix' in result:
+#             result['is_hash_id'] = True
+#         table.data = {**table.data,**result}
+#         # table.data['raw_yaml'] = result
+
+def _parse_comment_yaml(contents):
+    if len(contents) == 0:
+        return None
+    if isinstance(contents,(str)) is False:
+        contents = ""
+
+    # contents = contents.replace("\n","   ")
+    contents = contents.replace("desc:","description:")
+    contents = contents.replace("opts:","options:")
+    contents = contents.replace("o:","options:")
+
+    # contents = contents.replace("options:","options:\n")
+
+
+
+    if len(contents) > 0:
+        if contents.startswith("description:") is False:
+            contents = f"description: {contents}"
+
+        if "description:" not in contents:
+            contents = f"description: {contents}"
+    else:
+        return None
+    # @Mstep [] force a space between a dash and alphanum characters.
+    contents = _re.sub(r"\n-([a-zA-Z0-9])",r"\n- \1",contents)
+    # @Mstep [] force a space between a key's colon and the value following it.
+    contents = _re.sub(r"(\n-\s*[a-zA-Z0-9_ ]*:\s*)",r"\1 ",contents)
+
+    try:
+        # result = _parse_comment_yaml(comment)
+        data = yaml.safe_load(contents)
+    except yaml.scanner.ScannerError:
+        return None
+    # c.con.log(f"contents: {contents}","red")
+    output = {}
+    if "description" in data:
+        output['description'] = data['description']
+
+    if "options" in data:
+        if data['options'] is not None:
+            for opt in data['options']:
+                if isinstance(opt,(str)):
+                    output[_csu.to_snake_case(opt)] = True
+                if isinstance(opt,(dict)):
+                    for k,value in opt.items():
+                        output[_csu.to_snake_case(k)] = value
+    # print(output)
+    return output
 
-        Return {string}
-        ----------------------
-        The formatted SQL
 
-        Meta
-        ----------
-        `author`: Colemen Atwood
-        `created`: 03-21-2022 12:38:32
-        `version`: 1.0
-        `method_name`: format_sql_string
-        @xxx [03-21-2022 12:38:41]: documentation for format_sql_string
-    '''
-    if _f.exists(sql):
-        sql = _f.readr(sql)
 
-    sql = _csu.strip_empty_lines(sql)
 
-    raw = sql
-    # raw = _re.sub(r'^[\n]*','',raw)
-    statements = _sqlparse.split(raw)
-    new_contents = []
-    for state in statements:
-        state = _re.sub(r'^[\s\n]*','',state)
-        new_state = _sqlparse.format(state, reindent=True, keyword_case='upper')
-        new_contents.append(new_state)
-    if len(new_contents) > 0:
-        return "\n".join(new_contents)
-    return False
 
 def get_statements(sql:str):
     '''
@@ -1412,17 +1512,64 @@ def parse(sql):
 
         data['statements'].append(state)
 
+    data = _parse_data_comments(data)
+    return data
+
+def _parse_json_yaml(comment):
+    if comment is not None:
+        if isinstance(comment,(str)):
+            comment = _sql.escape_quoted_chars(comment,True)
+            json = _csu.parse.safe_load_json(comment)
+            if json:
+                return (comment,json)
+            else:
+                json = _parse_comment_yaml(comment)
+                if json:
+                    return (comment,json)
+    return (comment,{})
+
+def _parse_data_comments(data):
+    new_tables = []
     for tb in data['tables']:
-        if tb['comment'] is not None:
-            tb['comment'] = _sql.escape_quoted_chars(tb['comment'],True)
+        # print(f"tb['comment']:{tb['comment']}")
+        tb['comment'],json = _parse_json_yaml(tb['comment'])
+        tb['orig_comment'] = tb['comment']
+        tb['comment'] = json
+        # tb = {**tb,**json}
+        new_tables.append(tb)
+        # if tb['comment'] is not None:
+        #     tb['comment'] = _sql.escape_quoted_chars(tb['comment'],True)
+        #     json = _parse_comment_yaml(tb['comment'])
+        #     if json:
+        #         tb = {**tb,**json}
+
         if 'columns' in tb:
+            new_cols = []
             for col in tb['columns']:
-                if col['comment'] is not None:
-                    if isinstance(col['comment'],(str)):
-                        col['comment'] = _sql.escape_quoted_chars(col['comment'],True)
-                        json = _csu.parse.safe_load_json(col['comment'])
-                        if json:
-                            col['comment'] = json
+                col['comment'],json = _parse_json_yaml(col['comment'])
+                col = {**col,**json}
+                new_cols.append(col)
+
+                # col['comment']
+                # if col['comment'] is not None:
+                #     if isinstance(col['comment'],(str)):
+                #         col['comment'] = _sql.escape_quoted_chars(col['comment'],True)
+                #         json = _csu.parse.safe_load_json(col['comment'])
+                #         if json:
+                #             col = {**col,**json}
+                #             col['json_comment_found'] = True
+                #             new_cols.append(col)
+                #         else:
+                #             json = _parse_comment_yaml(col['comment'])
+                #             if json:
+                #                 col = {**col,**json}
+                #                 col['yaml_comment_found'] = True
+                #                 new_cols.append(col)
+                # else:
+                    # new_cols.append(col)
+            tb['columns'] = new_cols
+        # new_tables.append(tb)
+    data['tables'] = new_tables
     return data
 
 
@@ -1431,6 +1578,3 @@ def parse(sql):
 
 
 
-
-
-
